<?php
// This file contains functions used by the admin interface
// for the Caribou Lou's shopping cart.

function display_category_form($category = '') {
// This displays the category form.
// This form can be used for inserting or editing categories.
// To insert, don't pass any parameters.  This will set $edit
// to false, and the form will go to insert_category_project.php.
// To update, pass an array containing a category.  The
// form will contain the old data and point to update_category_project.php.
// It will also add a "Delete category" button.

  // if passed an existing category, proceed in "edit mode"
  $edit = is_array($category);

  // most of the form is in plain HTML with some
  // optional PHP bits throughout
?>
  <form method="post"
      action="<?php echo $edit ? 'edit_category_project.php' : 'insert_category_project.php'; ?>">
  <table border="0">
  <tr>
    <td>Category Name:</td>
    <td><input type="text" name="catname" size="40" maxlength="40"
          value="<?php echo $edit ? $category['catname'] : ''; ?>" /></td>
   </tr>
  <tr>
    <td <?php if (!$edit) { echo "colspan=2";} ?> align="center">
      <?php
         if ($edit) {
            echo "<input type=\"hidden\" name=\"cat_id\" value=\"".$category['cat_id']."\" />";
         }
      ?>
      <input type="submit"
       value="<?php echo $edit ? 'Update' : 'Add'; ?> Category" /></form>
     </td>
     <?php
        if ($edit) {
          //allow deletion of existing categories
          echo "<td>
                <form method=\"post\" action=\"delete_category_project.php\">
                <input type=\"hidden\" name=\"cat_id\" value=\"".$category['cat_id']."\" />
                <input type=\"submit\" value=\"Delete category\" />
                </form></td>";
       }
     ?>
  </tr>
  </table>
<?php
}

function display_media_form($media = '') {
// This displays the media form.
// It is very similar to the category form.
// This form can be used for inserting or editing media.
// To insert, don't pass any parameters. This will set $edit
// to false, and the form will go to insert_media_project.php.
// To update, pass an array containing media. The
// form will be displayed with the old data and point to edit_media_project.php.
// It will also add a "Delete media" button.


  // if passed an existing media, proceed in "edit mode"
  $edit = is_array($media);

  // most of the form is in plain HTML with some
  // optional PHP bits throughout
?>
  <form method="post"
        action="<?php echo $edit ? 'edit_media_project.php' : 'insert_media_project.php';?>">
  <table border="0">
  <tr>
    <td>Media ID:</td>
    <td><input type="text" name="media_id"
         value="<?php echo $edit ? $media['media_id'] : ''; ?>" /></td>
  </tr>
  <tr>
    <td>Title:</td>
    <td><input type="text" name="title"
         value="<?php echo $edit ? $media['title'] : ''; ?>" /></td>
  </tr>
  <tr>
    <td>Artist/Actor/Director:</td>
    <td><input type="text" name="artist"
         value="<?php echo $edit ? $media['artist'] : ''; ?>" /></td>
   </tr>
   <tr>
      <td>Category:</td>
      <td><select name="cat_id">
      <?php
          // list of possible categories comes from database
          $cat_array=get_categories();
          foreach ($cat_array as $thiscat) {
               echo "<option value=\"".$thiscat['cat_id']."\"";
               // if existing media, put in current catgory
               if (($edit) && ($thiscat['cat_id'] == $media['cat_id'])) {
                   echo " selected";
               }
               echo ">".$thiscat['catname']."</option>";
          }
          ?>
          </select>
        </td>
   </tr>
   <tr>
    <td>Price:</td>
    <td><input type="text" name="price"
               value="<?php echo $edit ? $media['price'] : ''; ?>" /></td>
   </tr>
   <tr>
     <td>Description:</td>
     <td><textarea rows="3" cols="50"
          name="description"><?php echo $edit ? $media['description'] : ''; ?></textarea></td>
    </tr>
    <tr>
      <td <?php if (!$edit) { echo "colspan=2"; }?> align="center">
         <?php
            if ($edit)
             // we need the old media ID to find media in database
             // if the media ID is being updated
             echo "<input type=\"hidden\" name=\"oldmedia_id\"
                    value=\"".$media['media_id']."\" />";
         ?>
        <input type="submit"
               value="<?php echo $edit ? 'Update' : 'Add'; ?> Media" />
        </form></td>
        <?php
           if ($edit) {
             echo "<td>
                   <form method=\"post\" action=\"delete_media_project.php\">
                   <input type=\"hidden\" name=\"media_id\"
                    value=\"".$media['media_id']."\" />
                   <input type=\"submit\" value=\"Delete media\"/>
                   </form></td>";
            }
          ?>
         </td>
      </tr>
  </table>
  </form>
<?php
}

function display_password_form() {
// displays html change password form
?>
   <br />
   <form action="change_password.php" method="post">
   <table width="250" cellpadding="2" cellspacing="0" bgcolor="#cccccc">
   <tr><td>Old password:</td>
       <td><input type="password" name="old_passwd" size="16" maxlength="16" /></td>
   </tr>
   <tr><td>New password:</td>
       <td><input type="password" name="new_passwd" size="16" maxlength="16" /></td>
   </tr>
   <tr><td>Repeat new password:</td>
       <td><input type="password" name="new_passwd2" size="16" maxlength="16" /></td>
   </tr>
   <tr><td colspan=2 align="center"><input type="submit" value="Change password">
   </td></tr>
   </table>
   <br />
<?php
}

function insert_category($catname) {
// inserts a new category into the database

   $conn = db_connect();

   // check category does not already exist
   $query = "select *
             from categories
             where catname='".$catname."'";
   $result = $conn->query($query);
   if ((!$result) || ($result->num_rows!=0)) {
     return false;
   }

   // insert new category
   $query = "insert into categories values
            ('', '".$catname."')";
   $result = $conn->query($query);
   if (!$result) {
     return false;
   } else {
     return true;
   }
}

function insert_media($media_id, $artist, $title, $cat_id, $price, $description) {
// insert new media into the database

   $conn = db_connect();

   // check media does not already exist
   $query = "select *
             from media
             where media_id='".$media_id."'";

   $result = $conn->query($query);
   if ((!$result) || ($result->num_rows!=0)) {
     return false;
   }

   // insert new media
   $query = "insert into media values
            ('".$media_id."', '".$artist."', '".$title."',
             '".$cat_id."', '".$price."', '".$description."')";

   $result = $conn->query($query);
   if (!$result) {
     return false;
   } else {
     return true;
   }
}

function update_category($cat_id, $catname) {
// change the name of category with cat_id in the database

   $conn = db_connect();

   $query = "update categories
             set catname='".$catname."'
             where cat_id='".$cat_id."'";
   $result = @$conn->query($query);
   if (!$result) {
     return false;
   } else {
     return true;
   }
}

function update_media($oldmedia_id, $media_id, $artist, $title, $cat_id,
                     $price, $description) {
// change details of media stored under $oldmedia_id in
// the database to new details in arguments

   $conn = db_connect();

   $query = "update media
             set media_id= '".$media_id."',
             artist = '".$artist."',
             title = '".$title."',
             cat_id = '".$cat_id."',
             price = '".$price."',
             description = '".$description."'
             where media_id = '".$oldmedia_id."'";

   $result = @$conn->query($query);
   if (!$result) {
     return false;
   } else {
     return true;
   }
}

function delete_category($cat_id) {
// Remove the category identified by cat_id from the db
// If there are media in the category, it will not
// be removed and the function will return false.

   $conn = db_connect();

   // check if there are any media in category
   // to avoid deletion anomalies
   $query = "select *
             from media
             where cat_id='".$cat_id."'";

   $result = @$conn->query($query);
   if ((!$result) || (@$result->num_rows > 0)) {
     return false;
   }

   $query = "delete from categories
             where cat_id='".$cat_id."'";
   $result = @$conn->query($query);
   if (!$result) {
     return false;
   } else {
     return true;
   }
}


function delete_media($media_id) {
// Deletes the media identified by $media_id from the database.

   $conn = db_connect();

   $query = "delete from media
             where media_id='".$media_id."'";
   $result = @$conn->query($query);
   if (!$result) {
     return false;
   } else {
     return true;
   }
}

?>